==> distribution-6.0.0-dev.128.zip: drr/regulation/common/validation/exists/ReportablePriceSourceOnlyExistsValidator.java <==
package drr.regulation.common.validation.exists;

import cdm.base.staticdata.asset.common.metafields.ReferenceWithMetaProductIdentifier;
import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidationResult.ValidationType;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.regulation.common.ReportablePriceSource;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class ReportablePriceSourceOnlyExistsValidator implements ValidatorWithArg<ReportablePriceSource, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends ReportablePriceSource> ValidationResult<ReportablePriceSource> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("productIdentifier", ExistenceChecker.isSet((List<? extends ReferenceWithMetaProductIdentifier>) o.getProductIdentifier()))
				.put("otherId", ExistenceChecker.isSet((String) o.getOtherId()))
				.put("underlyingAssetPriceSource", ExistenceChecker.isSet((String) o.getUnderlyingAssetPriceSource()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("ReportablePriceSource", ValidationType.ONLY_EXISTS, "ReportablePriceSource", path, "");
		}
		return failure("ReportablePriceSource", ValidationType.ONLY_EXISTS, "ReportablePriceSource", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}

==> distribution-6.19.3.zip: drr/regulation/common/validation/exists/ReportablePriceSourceOnlyExistsValidator.java <==
package drr.regulation.common.validation.exists;

import cdm.base.staticdata.asset.common.metafields.ReferenceWithMetaProductIdentifier;
import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.regulation.common.ReportablePriceSource;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class ReportablePriceSourceOnlyExistsValidator implements ValidatorWithArg<ReportablePriceSource, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends ReportablePriceSource> ValidationResult<ReportablePriceSource> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("productIdentifier", ExistenceChecker.isSet((List<? extends ReferenceWithMetaProductIdentifier>) o.getProductIdentifier()))
				.put("otherId", ExistenceChecker.isSet((String) o.getOtherId()))
				.put("underlyingAssetPriceSource", ExistenceChecker.isSet((String) o.getUnderlyingAssetPriceSource()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("ReportablePriceSource", ValidationResult.ValidationType.ONLY_EXISTS, "ReportablePriceSource", path, "");
		}
		return failure("ReportablePriceSource", ValidationResult.ValidationType.ONLY_EXISTS, "ReportablePriceSource", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}
